m32

Struct m32 

pub struct m32(/* private fields */);
Mask type with 32 bits. Its bit pattern is either all ones or all zeros. Unsafe code must not depend on this, however.

Implementations

Source

impl m32

pub const fn new(flag: bool) -> Self

Returns a mask with all bits set one, if flag is true, otherwise returns a mask with all bits set to zero.

pub const fn is_set(self) -> bool

Returns false if the mask bits are all zero, otherwise returns true.